# -*-coding=utf-8 -*-

from assertpy import assert_that
from ztDemo.common.data_processor import data_provider
from ztDemo.common.my_logger import MyLogger
from ztDemo.common.test_decorator import Test
from ztDemo.my_pages.login_page import LoginAPI, LoginPage
from ztDemo.settings.global_config import get_config


log = MyLogger(file_name='debug_info.log').get_logger(__name__)


class ZenTaoTest:
    test_case_id = 'Jira-1025'

    @data_provider([('itesting', 'P@ssw0rd', '测试账户')])
    # 给测试方法添加tag标签，指定其tag值为smoke
    @Test(tag='API')
    def test_login(self, *test_data):
        env = get_config('config')
        login_page = LoginAPI(env["DOMAIN"])
        user_name, password, accounts_name = test_data
        log.info("用户名是{0}, 密码是{1}, 账户登录态是{2}".format(user_name, password, accounts_name))
        result = login_page.login(user_name, password)
        assert_that(result.status_code).is_equal_to(200)
        assert_that(result.text).contains(accounts_name)
        assert_that(result.text).contains("退出")

    @data_provider([('itesting', 'P@ssw0rd', '测试账户')])
    @Test(tag='UI')
    def test_ui_login(self, *test_data):
        env = get_config('config')
        login_page = LoginPage('chrome', env["DOMAIN"])
        user_name, password, accounts_name = test_data
        log.info("用户名是{0}, 密码是{1}, 账户登录态是{2}".format(user_name, password, accounts_name))
        login_page.login(user_name, password)



import time

import requests
from selenium import webdriver


def cookie_to_selenium_format(cookie):
    cookie_selenium_mapping = {'path': '', 'secure': '', 'name': '', 'value': '', 'expires': ''}
    cookie_dict = {}
    if getattr(cookie, 'domain_initial_dot'):
        cookie_dict['domain'] = '.' + getattr(cookie, 'domain')
    else:
        cookie_dict['domain'] = getattr(cookie, 'domain')
    for k in list(cookie_selenium_mapping.keys()):
        key = k
        value = getattr(cookie, k)
        cookie_dict[key] = value
    return cookie_dict


class BasePage:
    def __init__(self, driver, base_url=None):
        if str(driver).capitalize() == "Chrome":
            self.driver = webdriver.Chrome()
        elif str(driver).capitalize() == "Firefox":
            self.driver = webdriver.Firefox()
        elif str(driver).capitalize() == "Safari":
            self.driver = webdriver.Safari()
        else:
            self.driver = webdriver.Chrome()
        self.base_url = base_url

    def open_page(self, url):
        self.driver.get(url)

    def is_element_exists(self, ele):
        time_out = 60
        flag = False
        while time_out > 0:
            try:
                self.driver.find_element(*ele)
                flag = True
                break
            except:
                time_out -= 1
                time.sleep(0.5)
        return flag

    def close_page(self):
        self.driver.quit()

    def open_page(self, url):
        self.driver.get(url)

    def is_element_exists(self, ele):
        time_out = 60
        flag = False
        while time_out > 0:
            try:
                self.driver.find_element(*ele)
                flag = True
                break
            except:
                time_out -= 1
                time.sleep(0.5)
        return flag

    def page_go(self, cookies):
        self.driver.get(self.page_url)
        time.sleep(1)

        # 删除所有cookies
        self.driver.delete_all_cookies()

        # 针对获取到API登录的cookie，写入WebDriver里
        for k, v in cookies.items():
            self.driver.add_cookie(cookie_to_selenium_format(v))
        time.sleep(1)
        # 此时， 拿到了登录态
        self.driver.get(self.page_url)


class BaseAPIPage:
    header_form = {'Content-Type': 'application/x-www-form-urlencoded', 'charset': 'UTF-8'}
    header_json = {'Content-Type': 'application/json', 'charset': 'UTF-8'}

    def __init__(self, url=None):
        self.driver = requests.session()
        self.base_url = url

    def post_api(self, url, headers=header_json, **kwargs):
        return self.driver.post(url, headers=headers, **kwargs)

    def get_api(self, url, headers=header_json, **kwargs):
        return self.driver.get(url, headers=headers, **kwargs)

    def put_api(self):
        pass



from selenium.webdriver.common.by import By

from ztDemo.my_pages.base_page import BasePage


class ScorePage(BasePage):

    score_status = (By.XPATH, '//div[@class="panel-heading"]/strong')

    def __init__(self, driver, url):
        super().__init__(driver, url)
        self.page_url = self.base_url + '/user-score.html'

    def get_score_text(self):
        if self.is_element_exists(self.score_status):
            return self.driver.find_element(*self.score_status).get_attribute("innerHTML")
        return None






from selenium.webdriver.common.by import By
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.support import expected_conditions as EC, wait

from ..my_pages.base_page import BaseAPIPage, BasePage


class LoginPage(BasePage):
    input_email = (By.ID, "account")
    input_password = (By.ID, "password")
    button_login = (By.XPATH, '//*[@id="submit"]')
    user_status_after_login = (By.XPATH, '//*[@id="siteNav"]/a[2]')
    login_via_account = (By.XPATH, '//*[@id="loginCommon"]/ul/li[3]/a')
    we_chat_qr_code = (By.ID, 'qrcode')

    def __init__(self, driver, url):
        super().__init__(driver, url)
        self.page_url = self.base_url + '/user-login.html'

    def login(self, user_name, password):
        self.open_page(self.page_url)
        self.driver.implicitly_wait(10)

        wait.WebDriverWait(self.driver, 10).until(EC.presence_of_element_located((By.ID, 'qrcode')))
        assert self.driver.find_element(*self.we_chat_qr_code).is_displayed()
        self.driver.find_element(*self.login_via_account).click()
        assert self.driver.find_element(*self.input_email).is_displayed()
        self.driver.find_element(*self.input_email).clear()
        self.driver.find_element(*self.input_email).send_keys(user_name)
        self.driver.find_element(*self.input_password).clear()
        self.driver.find_element(*self.input_password).send_keys(password)
        self.driver.find_element(*self.input_password).send_keys(Keys.RETURN)
        text = self.get_login_user_text()
        assert "退出" in text

    def get_login_user_text(self):
        if self.is_element_exists(self.user_status_after_login):
            return self.driver.find_element(*self.user_status_after_login).text
        return None


class LoginAPI(BaseAPIPage):

    def __init__(self, url):
        super().__init__(url)
        self.page_url = self.base_url + '/user-login.html'

    def login(self, user_name, password):
        data = {"account": user_name, "password": password}
        return self.post_api(self.page_url, headers=self.header_form, data=data)

    def get_login_cookie(self, user_name, password):
        self.login(user_name, password)
        # 获取Cookies
        return self.driver.cookies._cookies["www.zentao.net"]["/"]